@@ -1,4 +1,5 @@
 from Products.CMFCore.utils import getToolByName
+from zope.component.interfaces import ComponentLookupError
 
 def install_browserlayer(context):
     setup = getToolByName(context, 'portal_setup')
@@ -100,3 +101,41 @@ def upgrade_1894_1895(context):
     setup.runImportStepFromProfile('profile-collective.js.jqueryui:default',
                                    'cssregistry', run_dependencies=False,
                                     purge_old=False)
+
+def upgrade_1896_1898(context):
+    jsregistry = getToolByName(context, 'portal_javascripts')
+    cssregistry = getToolByName(context, 'portal_css')
+
+    setup = getToolByName(context, 'portal_setup')
+
+    jsregistry.unregisterResource('++resource++jquery-ui.min.js')
+    jsregistry.unregisterResource('++resource++jquery-ui-i18n.js') #will be readdded
+    cssregistry.unregisterResource('++resource++jquery-ui-themes/sunburst/jqueryui.css')
+    cssregistry.unregisterResource('++resource++jquery-ui-themes/sunburst-patch.css')
+
+    setup.runImportStepFromProfile('profile-collective.js.jqueryui:default',
+                                   'jsregistry', run_dependencies=False,
+                                   purge_old=False)
+    setup.runImportStepFromProfile('profile-collective.js.jqueryui:default',
+                                   'cssregistry', run_dependencies=False,
+                                   purge_old=False)
+    setup.runImportStepFromProfile('profile-collective.js.jqueryui:default',
+                                   'actions', run_dependencies=False,
+                                   purge_old=False)
+    setup.runImportStepFromProfile('profile-collective.js.jqueryui:default',
+                                   'controlpanel', run_dependencies=False,
+                                   purge_old=False)
+
+    #We choose to activate all plugins for compatibility purpose.
+    #but we need to be sure plone.app.registry is installed
+    from zope.component import getUtility
+    from plone.registry.interfaces import IRegistry
+    #is plone.app.registry
+    try:
+        registry = getUtility(IRegistry)
+    except ComponentLookupError:
+        setup.runAllImportStepsFromProfile('profile-plone.app.registry:default')
+
+    setup.runImportStepFromProfile('profile-collective.js.jqueryui:default',
+                                   'plone.app.registry', run_dependencies=False,
+                                   purge_old=False)
